==> senior_design_system-0.21.4.tar.gz: example/lib/pages/backdrop.example.dart <==
import 'package:flutter/material.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_system/senior_design_system.dart';

class BackdropExample extends StatefulWidget {
  const BackdropExample({Key? key}) : super(key: key);

  @override
  _BackdropExampleState createState() => _BackdropExampleState();
}

class _BackdropExampleState extends State<BackdropExample> with SingleTickerProviderStateMixin {
  late TabController tabController;

  @override
  void initState() {
    super.initState();

    tabController = TabController(
      initialIndex: 0,
      vsync: this,
      length: 6,
    );
  }

  @override
  Widget build(BuildContext context) {
    return SeniorBackdrop(
      centerTitle: true,
      hideLeading: true,
      title: Text('Senior Backdrop'),
      style: SeniorBackdropStyle(
        bodyColor: SeniorColors.pureBlack,
      ),
      body: ListView.separated(
        itemCount: 500000,
        scrollDirection: Axis.vertical,
        separatorBuilder: (BuildContext context, int index) => VerticalDivider(),
        itemBuilder: (BuildContext context, int index) {
          return Container(
            width: 40,
            child: Text(
              'item $index',
              style: TextStyle(color: Colors.white),
            ),
          );
        },
      ),
      backdropTabBarInfo: SeniorBackdropTabBarInfo(
        tabs: [
          'Pagar',
          'Receber',
          'Cotas',
          'NFe',
          'Notificação',
          'Pedidos',
        ],
        onTap: (int) {},
        initialIndex: 0,
        controller: tabController,
        isScrollable: true,
      ),
    );
  }
}

==> senior_design_system-6.0.0.tar.gz: example/lib/pages/backdrop.example.dart <==
import 'package:flutter/material.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_system/senior_design_system.dart';

class BackdropExample extends StatefulWidget {
  const BackdropExample({Key? key}) : super(key: key);

  @override
  _BackdropExampleState createState() => _BackdropExampleState();
}

class _BackdropExampleState extends State<BackdropExample>
    with SingleTickerProviderStateMixin {
  late TabController tabController;

  @override
  void initState() {
    super.initState();

    tabController = TabController(
      initialIndex: 0,
      vsync: this,
      length: 6,
    );
  }

  @override
  Widget build(BuildContext context) {
    return SeniorBackdrop(
      centerTitle: true,
      hideLeading: true,
      title: const Text('Senior Backdrop'),
      style: const SeniorBackdropStyle(
        bodyColor: SeniorColors.pureBlack,
      ),
      body: ListView.separated(
        itemCount: 500000,
        scrollDirection: Axis.vertical,
        separatorBuilder: (BuildContext context, int index) =>
            const VerticalDivider(),
        itemBuilder: (BuildContext context, int index) {
          return Container(
            width: 40,
            child: Text(
              'item $index',
              style: const TextStyle(color: Colors.white),
            ),
          );
        },
      ),
      backdropTabBarInfo: SeniorBackdropTabBarInfo(
        tabs: [
          'Pagar',
          'Receber',
          'Cotas',
          'NFe',
          'Notificação',
          'Pedidos',
        ],
        onTap: (int value) {},
        initialIndex: 0,
        controller: tabController,
        isScrollable: true,
      ),
    );
  }
}
